function [Simu] = launch_AR_regression_with_Gibbs_sampler(y,AR_lags,nb_MCMC,graph)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Function : Simulation of parameter posterior distributions of an AR process of order AR_lags using Gibbs sampler 
%%%%% and computation of MLLs according to different methods
%%%%% (Chib,Importance Sampling,Harmonic Mean)
%%%%% Be careful :  Harmonic mean estimator
%%%%% requires too many draws to converge to the true estimate. Do not use
%%%%% it in practice.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Inputs : 
%%%%% y contains the dependent variable (T * 1)
%%%%% AR_lags stands for the order of the AR process (default = 1)
%%%%% nb_MCMC : number of MCMC iterations  (default = 5000)
%%%%% graph : if =1, some convergence graphics are displayed at the end of
%%%%% the simulation (by default = 0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Outputs :
%%%%% Simu is a structure containing :
%%%%% - post_beta and post_sigma : MCMC Posterior draws of Beta and sigma^2
%%%%% under CP priors
%%%%% - beta_ols and sigma_ols are the OLS results.
%%%%% - MLL_Chib : MLL computed from MCMC output
%%%%% - MLL_IS : MLL computed by IS
%%%%% - MLL_HM : MLL computed by Harmonic mean 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(nargin<4)
    graph = 0;
    if(nargin<3)
        nb_MCMC = 5000;
        if(nargin<2)
            AR_lags = 1;
        end
    end
end



[X y] = AR_explanatory_var(y,AR_lags);
[Simu] = Gibbs_regression_with_MLL(y,X,nb_MCMC,graph); %#ok<AGROW>
Simu.X = X;
