function [Simu MLL] = launch_CP_model_estimations(y,AR_lags,upper_bound_regime,nb_MCMC)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% function that simulates several posterior distributions of CP-AR(p) models
%%%%% starting from a number of regime = 1 to a number of regime =
%%%%% upper_bound_regime. At each time, the Maginal log likelihood is
%%%%% computed and stored in the table MLL. 
%%%%% The order of the AR process is determined by AR_lags
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Inputs : 
%%%%% y contains the dependent variable (T * 1)
%%%%% AR_lags : the order of the AR process
%%%%% upper_bound_regime : The maximum number of regime considered
%%%%% nb_MCMC : number of MCMC iterations (10000 by default)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Outputs :
%%%%% Simu is a structure containing :
%%%%% - post_beta and post_sigma : MCMC Posterior draws of Beta and sigma^2
%%%%% under CP priors
%%%%% - post_tau : MCMC posterior draws of the break dates
%%%%% - post_trans_mat : posterior draw of the diagonal of the transition
%%%%% matrix
%%%%% - post_like : the posterior densities of the drawn parameters
%%%%% - MLL : the marginal likelihood of the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% EXAMPLE FOR RuNNING THE PROGRAM :
%%%%%%%% [Simu MLL] = launch_CP_model_estimations(y,1,3,10000)
%%%%% Run a CP-AR(1) model with one,two and three regimes simulated with
%%%%% 10000 MCMC iterations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if(nargin<4)
    nb_MCMC = 10000;
end
[X y] = AR_explanatory_var(y,AR_lags);
MLL = zeros(upper_bound_regime,1);
for q=1:upper_bound_regime
    disp('********************************************************************************************');
    disp(['***** Estimation of CP-AR(' num2str(AR_lags) ') model with ' num2str(q) ' regimes  *******']);
    disp('********************************************************************************************');
   [Simu(q)] = Gibbs_regression_chib(y,X,q,nb_MCMC,0,1);  %#ok<*AGROW>
   MLL(q) = Simu(q).MLL;
end
[~,ind] = max(MLL);
disp('*****************************************************');
disp(['* The best model contains ' num2str(ind) ' regimes *'])
disp('*****************************************************');
